@@ -9,11 +9,12 @@ import (
 	"github.com/urfave/cli"
 	"go.uber.org/automaxprocs/maxprocs"
 
+	"gitlab.com/gitlab-org/gitlab-runner/commands"
+	"gitlab.com/gitlab-org/gitlab-runner/commands/helpers"
+	"gitlab.com/gitlab-org/gitlab-runner/commands/steps"
 	"gitlab.com/gitlab-org/gitlab-runner/common"
 	"gitlab.com/gitlab-org/gitlab-runner/log"
-
-	_ "gitlab.com/gitlab-org/gitlab-runner/commands/helpers"
-	_ "gitlab.com/gitlab-org/gitlab-runner/commands/steps"
+	"gitlab.com/gitlab-org/gitlab-runner/network"
 )
 
 func init() {
@@ -43,7 +44,7 @@ func main() {
 			Email: "support@gitlab.com",
 		},
 	}
-	app.Commands = common.GetCommands()
+	app.Commands = newCommands()
 	app.CommandNotFound = func(context *cli.Context, command string) {
 		logrus.Fatalln("Command", command, "not found")
 	}
@@ -54,3 +55,20 @@ func main() {
 		logrus.Fatal(err)
 	}
 }
+
+func newCommands() []cli.Command {
+	n := network.NewGitLabClient(
+		network.WithCertificateDirectory(commands.GetDefaultCertificateDirectory()),
+	)
+	return []cli.Command{
+		helpers.NewArtifactsDownloaderCommand(n),
+		helpers.NewArtifactsUploaderCommand(n),
+		helpers.NewCacheArchiverCommand(),
+		helpers.NewCacheExtractorCommand(),
+		helpers.NewCacheInitCommand(),
+		helpers.NewHealthCheckCommand(),
+		helpers.NewProxyExecCommand(),
+		helpers.NewReadLogsCommand(),
+		steps.NewCommand(),
+	}
+}
