@@ -3,9 +3,9 @@
 package s3v2
 
 import (
-	"context"
 	"errors"
 	"fmt"
+	"net/http"
 	"net/url"
 	"testing"
 	"time"
@@ -42,8 +42,11 @@ type cacheOperationTest struct {
 	errorOnS3ClientInitialization bool
 	errorOnURLPresigning          bool
 
-	presignedURL *url.URL
-	expectedURL  *url.URL
+	metadata                map[string]string
+	presignedURL            *url.URL
+	expectedURL             *url.URL
+	expectedUploadHeaders   http.Header
+	expectedDownloadHeaders http.Header
 }
 
 func onFakeS3URLGenerator(t *testing.T, tc cacheOperationTest) {
@@ -56,8 +59,13 @@ func onFakeS3URLGenerator(t *testing.T, tc cacheOperationTest) {
 
 	client.
 		On(
-			"PresignURL", mock.Anything, mock.Anything, mock.Anything,
-			mock.Anything, mock.Anything,
+			"PresignURL",
+			mock.Anything, // context
+			mock.Anything, // http method
+			mock.Anything, // bucket name
+			mock.Anything, // object name
+			mock.Anything, // metadata
+			mock.Anything, // valid time
 		).
 		Return(cache.PresignedURL{URL: tc.presignedURL}, err).Maybe()
 
@@ -93,10 +101,21 @@ func testCacheOperation(
 		}
 		require.NoError(t, err)
 
+		adapter.WithMetadata(tc.metadata)
+
 		URL := operation(adapter)
 		assert.Equal(t, tc.expectedURL, URL.URL)
 
-		ctx := context.Background()
+		switch operationName {
+		case "GetUploadURL":
+			assert.Equal(t, tc.expectedUploadHeaders, URL.Headers, "upload headers")
+		case "GetDownloadURL":
+			assert.Equal(t, tc.expectedDownloadHeaders, URL.Headers, "download headers")
+		default:
+			// nothing to do (yet)
+		}
+
+		ctx := t.Context()
 
 		goCloudURL, err := adapter.GetGoCloudURL(ctx, true)
 		assert.NoError(t, err)
@@ -127,6 +146,12 @@ func TestCacheOperation(t *testing.T) {
 			presignedURL: URL,
 			expectedURL:  URL,
 		},
+		"presigned-url-with-metadata": {
+			presignedURL:          URL,
+			metadata:              map[string]string{"foo": "some foo"},
+			expectedURL:           URL,
+			expectedUploadHeaders: http.Header{"X-Amz-Meta-Foo": []string{"some foo"}},
+		},
 	}
 
 	for testName, test := range tests {
@@ -134,14 +159,14 @@ func TestCacheOperation(t *testing.T) {
 			testCacheOperation(
 				t,
 				"GetDownloadURL",
-				func(adapter cache.Adapter) cache.PresignedURL { return adapter.GetDownloadURL(context.Background()) },
+				func(adapter cache.Adapter) cache.PresignedURL { return adapter.GetDownloadURL(t.Context()) },
 				test,
 				defaultCacheFactory(),
 			)
 			testCacheOperation(
 				t,
 				"GetUploadURL",
-				func(adapter cache.Adapter) cache.PresignedURL { return adapter.GetUploadURL(context.Background()) },
+				func(adapter cache.Adapter) cache.PresignedURL { return adapter.GetUploadURL(t.Context()) },
 				test,
 				defaultCacheFactory(),
 			)
@@ -331,7 +356,7 @@ func TestGoCloudURLWithRoleARN(t *testing.T) {
 						Return(expectedCredentials, nil).Maybe()
 				}
 
-				u, err := adapter.GetGoCloudURL(context.Background(), uploadMode)
+				u, err := adapter.GetGoCloudURL(t.Context(), uploadMode)
 
 				if tt.failedFetch {
 					assert.Error(t, err)
@@ -529,7 +554,7 @@ func TestGoCloudURLWithUploadRoleARN(t *testing.T) {
 				}
 			}
 
-			u, err := adapter.GetGoCloudURL(context.Background(), true)
+			u, err := adapter.GetGoCloudURL(t.Context(), true)
 
 			if tt.failedFetch {
 				assert.Error(t, err)
@@ -549,7 +574,7 @@ func TestGoCloudURLWithUploadRoleARN(t *testing.T) {
 				assert.Nil(t, u.URL)
 			}
 
-			du, err := adapter.GetGoCloudURL(context.Background(), false)
+			du, err := adapter.GetGoCloudURL(t.Context(), false)
 			require.NoError(t, err)
 			assert.Nil(t, du.URL)
 			assert.Empty(t, du.Environment)
