@@ -9,7 +9,7 @@ import (
 	"sync"
 	"time"
 
-	"github.com/docker/docker/api/types"
+	"github.com/docker/docker/api/types/container"
 	"github.com/sirupsen/logrus"
 
 	"gitlab.com/gitlab-org/gitlab-runner/common"
@@ -24,19 +24,17 @@ import (
 const (
 	buildContainerType      = "build"
 	predefinedContainerType = "predefined"
-	stepRunnerContainerType = "step-runner"
 )
 
 type commandExecutor struct {
 	executor
-	helperContainer                 *types.ContainerJSON
-	buildContainer                  *types.ContainerJSON
+	helperContainer                 *container.InspectResponse
+	buildContainer                  *container.InspectResponse
 	lock                            sync.Mutex
 	terminalWaitForContainerTimeout time.Duration
-	stepRunnerContainerOnce         sync.Once
 }
 
-func (s *commandExecutor) getBuildContainer() *types.ContainerJSON {
+func (s *commandExecutor) getBuildContainer() *container.InspectResponse {
 	s.lock.Lock()
 	defer s.lock.Unlock()
 
@@ -87,15 +85,6 @@ func (s *commandExecutor) isUmaskDisabled() bool {
 
 func (s *commandExecutor) Run(cmd common.ExecutorCommand) error {
 	if cmd.Predefined {
-		// if steps is enabled, run the step-runner container with the helper container. Eventually we can remove the
-		// helper execution path.
-		if s.Build.UseNativeSteps() {
-			var err error
-			s.stepRunnerContainerOnce.Do(func() { err = s.runContainer(stepRunnerContainerType, common.ExecutorCommand{Context: cmd.Context}) })
-			if err != nil {
-				return err
-			}
-		}
 		return s.runContainer(predefinedContainerType, cmd)
 	} else {
 		return s.runContainer(buildContainerType, cmd)
@@ -134,20 +123,18 @@ func (s *commandExecutor) runContainer(containerType string, cmd common.Executor
 	return runErr
 }
 
-func (s *commandExecutor) requestContainer(containerType string) (*types.ContainerJSON, error) {
+func (s *commandExecutor) requestContainer(containerType string) (*container.InspectResponse, error) {
 	switch containerType {
 	case buildContainerType:
 		return s.requestBuildContainer()
 	case predefinedContainerType:
 		return s.requestHelperContainer()
-	case stepRunnerContainerType:
-		return s.requestStepRunnerContainer()
 	default:
 		return nil, fmt.Errorf("invalid container-type %q", containerType)
 	}
 }
 
-func (s *commandExecutor) hasExistingContainer(containerType string, container *types.ContainerJSON) bool {
+func (s *commandExecutor) hasExistingContainer(containerType string, container *container.InspectResponse) bool {
 	if container == nil {
 		return false
 	}
@@ -166,7 +153,7 @@ func (s *commandExecutor) hasExistingContainer(containerType string, container *
 	return false
 }
 
-func (s *commandExecutor) requestHelperContainer() (*types.ContainerJSON, error) {
+func (s *commandExecutor) requestHelperContainer() (*container.InspectResponse, error) {
 	if s.hasExistingContainer(predefinedContainerType, s.helperContainer) {
 		return s.helperContainer, nil
 	}
@@ -204,9 +191,7 @@ func (s *commandExecutor) getHelperImageCmd() []string {
 	return s.helperImageInfo.Cmd
 }
 
-var stepRunnerServiceCommand = []string{"step-runner", "serve"}
-
-func (s *commandExecutor) requestBuildContainer() (*types.ContainerJSON, error) {
+func (s *commandExecutor) requestBuildContainer() (*container.InspectResponse, error) {
 	s.lock.Lock()
 	defer s.lock.Unlock()
 
@@ -217,7 +202,7 @@ func (s *commandExecutor) requestBuildContainer() (*types.ContainerJSON, error)
 	// Overwrite the build container command if using steps
 	cmd := s.BuildShell.DockerCommand
 	if s.Build.UseNativeSteps() {
-		cmd = stepRunnerServiceCommand
+		cmd = append([]string{bootstrappedBinary, "steps", "serve"}, s.BuildShell.DockerCommand...)
 	}
 
 	var err error
@@ -327,7 +312,7 @@ func (s *commandExecutor) executeChown(dockerExec exec.Docker, uid int, gid int)
 }
 
 func (s *commandExecutor) executeChownOnDir(
-	c *types.ContainerJSON,
+	c *container.InspectResponse,
 	dockerExec exec.Docker,
 	uid int,
 	gid int,
@@ -409,9 +394,14 @@ func init() {
 		DefaultShellName: options.Shell.Shell,
 	})
 
+	windowsFeaturesUpdater := func(features *common.FeaturesInfo) {
+		featuresUpdater(features)
+		features.NativeStepsIntegration = false
+	}
+
 	common.RegisterExecutorProvider("docker-windows", executors.DefaultExecutorProvider{
 		Creator:          creator,
-		FeaturesUpdater:  featuresUpdater,
+		FeaturesUpdater:  windowsFeaturesUpdater,
 		ConfigUpdater:    configUpdater,
 		DefaultShellName: options.Shell.Shell,
 	})
