@@ -4,6 +4,7 @@ package kubernetes
 
 import (
 	"bytes"
+	"context"
 	"fmt"
 	"io"
 	"net/http"
@@ -14,7 +15,6 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"golang.org/x/net/context"
 	api "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -476,6 +476,7 @@ func testKubernetesClient(version string, httpClient *http.Client) *kubernetes.C
 	conf := restclient.Config{
 		ContentConfig: restclient.ContentConfig{
 			GroupVersion: &schema.GroupVersion{Version: version},
+			ContentType:  runtime.ContentTypeJSON,
 		},
 	}
 	kube := kubernetes.NewForConfigOrDie(&conf)
