@@ -30,7 +30,8 @@ const (
 	clientError              = -100
 	responseBodyPeekMax      = 512
 
-	correlationIDHeader = "X-Request-Id"
+	correlationIDHeader   = "X-Request-Id"
+	correlationIDLogField = "correlation_id"
 )
 
 func TokenIsCreatedRunnerToken(token string) bool {
@@ -38,9 +39,9 @@ func TokenIsCreatedRunnerToken(token string) bool {
 }
 
 type GitLabClient struct {
-	clients map[string]*client
-	lock    sync.Mutex
-
+	clients              map[string]*client
+	lock                 sync.Mutex
+	certDirectory        string
 	apiRequestsCollector *APIRequestsCollector
 	connectionMaxAge     time.Duration
 }
@@ -64,7 +65,12 @@ func (n *GitLabClient) getClient(credentials requestCredentials) (*client, error
 		return c, nil
 	}
 
-	c, err := newClient(credentials, n.apiRequestsCollector, WithMaxAge(n.connectionMaxAge))
+	c, err := newClient(
+		credentials,
+		n.apiRequestsCollector,
+		withMaxAge(n.connectionMaxAge),
+		withCertificateDirectory(n.certDirectory),
+	)
 	if err != nil {
 		return nil, fmt.Errorf("new client: %w", err)
 	}
@@ -357,7 +363,7 @@ func (n *GitLabClient) RegisterRunner(
 	)
 	defer closeResponseBody(resp, false)
 
-	logger := runner.Log().WithField("correlation_id", getCorrelationID(resp, correlationID))
+	logger := runner.Log().WithField(correlationIDLogField, getCorrelationID(resp, correlationID))
 
 	switch result {
 	case http.StatusCreated:
@@ -413,7 +419,7 @@ func (n *GitLabClient) VerifyRunner(runner common.RunnerCredentials, systemID st
 	}
 	defer closeResponseBody(resp, false)
 
-	logger := runner.Log().WithField("correlation_id", getCorrelationID(resp, correlationID))
+	logger := runner.Log().WithField(correlationIDLogField, getCorrelationID(resp, correlationID))
 
 	switch result {
 	case http.StatusOK:
@@ -459,7 +465,7 @@ func (n *GitLabClient) UnregisterRunner(runner common.RunnerCredentials) bool {
 	)
 	defer closeResponseBody(resp, false)
 
-	logger := runner.Log().WithField("correlation_id", getCorrelationID(resp, correlationID))
+	logger := runner.Log().WithField(correlationIDLogField, getCorrelationID(resp, correlationID))
 
 	const baseLogText = "Unregistering runner from GitLab"
 	switch result {
@@ -498,7 +504,7 @@ func (n *GitLabClient) UnregisterRunnerManager(runner common.RunnerCredentials,
 	)
 	defer closeResponseBody(resp, false)
 
-	logger := runner.Log().WithField("correlation_id", getCorrelationID(resp, correlationID))
+	logger := runner.Log().WithField(correlationIDLogField, getCorrelationID(resp, correlationID))
 
 	const baseLogText = "Unregistering runner manager from GitLab"
 	switch result {
@@ -564,7 +570,7 @@ func (n *GitLabClient) resetToken(
 
 	defer closeResponseBody(resp, false)
 
-	logger := runner.Log().WithField("correlation_id", getCorrelationID(resp, correlationID))
+	logger := runner.Log().WithField(correlationIDLogField, getCorrelationID(resp, correlationID))
 
 	const baseLogText = "Resetting runner authentication token..."
 	switch result {
@@ -584,21 +590,23 @@ func (n *GitLabClient) resetToken(
 	}
 }
 
-func addTLSData(response *common.JobResponse, tlsData ResponseTLSData) {
+func loadTLSData(tlsData ResponseTLSData) common.TLSData {
+	var res common.TLSData
 	if tlsData.CAChain != "" {
-		response.TLSCAChain = tlsData.CAChain
+		res.CAChain = tlsData.CAChain
 	}
 
 	if tlsData.CertFile != "" && tlsData.KeyFile != "" {
 		data, err := os.ReadFile(tlsData.CertFile)
 		if err == nil {
-			response.TLSAuthCert = string(data)
+			res.AuthCert = string(data)
 		}
 		data, err = os.ReadFile(tlsData.KeyFile)
 		if err == nil {
-			response.TLSAuthKey = string(data)
+			res.AuthKey = string(data)
 		}
 	}
+	return res
 }
 
 func (n *GitLabClient) RequestJob(
@@ -635,7 +643,7 @@ func (n *GitLabClient) RequestJob(
 	)
 	defer closeResponseBody(httpResponse, false)
 
-	logger := config.Log().WithField("correlation_id", getCorrelationID(httpResponse, correlationID))
+	logger := config.Log().WithField(correlationIDLogField, getCorrelationID(httpResponse, correlationID))
 
 	switch result {
 	case http.StatusCreated:
@@ -649,8 +657,7 @@ func (n *GitLabClient) RequestJob(
 		if err != nil {
 			logger.WithError(err).Errorln("Error on fetching TLS Data from API response...", "error")
 		}
-		addTLSData(&response, tlsData)
-
+		response.TLSData = loadTLSData(tlsData)
 		response.JobRequestCorrelationID = getCorrelationID(httpResponse, correlationID)
 
 		return &response, true
@@ -687,15 +694,17 @@ func (n *GitLabClient) UpdateJob(
 		ExitCode:      jobInfo.ExitCode,
 	}
 
+	headers, correlationID := addCorrelationID(JobTokenHeader(jobCredentials.Token))
+
 	log := config.Log().WithFields(logrus.Fields{
-		"job":      jobInfo.ID,
-		"checksum": request.Output.Checksum,
-		"bytesize": request.Output.Bytesize,
+		"job":                 jobInfo.ID,
+		"checksum":            request.Output.Checksum,
+		"bytesize":            request.Output.Bytesize,
+		correlationIDLogField: correlationID,
 	})
 
 	log.Info("Updating job...")
 
-	headers, correlationID := addCorrelationID(JobTokenHeader(jobCredentials.Token))
 	//nolint:bodyclose
 	statusCode, statusText, response := n.doMeasuredJSON(
 		context.Background(),
@@ -734,10 +743,10 @@ func (n *GitLabClient) createUpdateJobResult(
 	}
 
 	log = log.WithFields(logrus.Fields{
-		"code":            statusCode,
-		"job-status":      remoteJobStateResponse.RemoteState,
-		"update-interval": remoteJobStateResponse.RemoteUpdateInterval,
-		"correlation_id":  getCorrelationID(response, fallbackCorrelationID),
+		"code":                statusCode,
+		"job-status":          remoteJobStateResponse.RemoteState,
+		"update-interval":     remoteJobStateResponse.RemoteUpdateInterval,
+		correlationIDLogField: getCorrelationID(response, fallbackCorrelationID),
 	})
 
 	switch {
@@ -818,13 +827,13 @@ func (n *GitLabClient) PatchTrace(
 
 	tracePatchResponse := NewTracePatchResponse(response, baseLog)
 	log := baseLog.WithFields(logrus.Fields{
-		"sent-log":        contentRange,
-		"job-log":         tracePatchResponse.RemoteRange,
-		"job-status":      tracePatchResponse.RemoteState,
-		"code":            response.StatusCode,
-		"status":          response.Status,
-		"update-interval": tracePatchResponse.RemoteUpdateInterval,
-		"correlation_id":  getCorrelationID(response, correlationID),
+		"sent-log":            contentRange,
+		"job-log":             tracePatchResponse.RemoteRange,
+		"job-status":          tracePatchResponse.RemoteState,
+		"code":                response.StatusCode,
+		"status":              response.Status,
+		"update-interval":     tracePatchResponse.RemoteUpdateInterval,
+		correlationIDLogField: getCorrelationID(response, correlationID),
 	})
 
 	return n.createPatchTraceResult(startOffset, tracePatchResponse, response, endOffset, log)
@@ -990,9 +999,9 @@ func (n *GitLabClient) UploadRawArtifacts(
 	defer closeResponseBody(res, true)
 
 	log := logrus.WithFields(logrus.Fields{
-		"id":             config.ID,
-		"token":          helpers.ShortenToken(config.Token),
-		"correlation_id": getCorrelationID(res, correlationID),
+		"id":                  config.ID,
+		"token":               helpers.ShortenToken(config.Token),
+		correlationIDLogField: getCorrelationID(res, correlationID),
 	})
 
 	if options.LogResponseDetails {
@@ -1120,9 +1129,9 @@ func (n *GitLabClient) DownloadArtifacts(
 	)
 
 	log := logrus.WithFields(logrus.Fields{
-		"id":             config.ID,
-		"token":          helpers.ShortenToken(config.Token),
-		"correlation_id": getCorrelationID(res, correlationID),
+		"id":                  config.ID,
+		"token":               helpers.ShortenToken(config.Token),
+		correlationIDLogField: getCorrelationID(res, correlationID),
 	})
 
 	if res != nil {
@@ -1185,7 +1194,13 @@ func (n *GitLabClient) ProcessJob(
 	config common.RunnerConfig,
 	jobCredentials *common.JobCredentials,
 ) (common.JobTrace, error) {
-	trace, err := newJobTrace(n, config, jobCredentials)
+	l := logrus.New().WithFields(logrus.Fields{
+		"runner":      config.ShortDescription(),
+		"runner_name": config.Name,
+		"job":         jobCredentials.ID,
+	})
+
+	trace, err := newJobTrace(n, config, jobCredentials, l)
 	if err != nil {
 		return nil, fmt.Errorf("create job trace: %w", err)
 	}
@@ -1204,14 +1219,29 @@ func closeResponseBody(res *http.Response, discardBody bool) {
 	_ = res.Body.Close()
 }
 
-func NewGitLabClientWithAPIRequestsCollector(c *APIRequestsCollector) *GitLabClient {
-	return &GitLabClient{
-		apiRequestsCollector: c,
+type ClientOption func(*GitLabClient)
+
+func WithAPIRequestsCollector(collector *APIRequestsCollector) ClientOption {
+	return func(c *GitLabClient) {
+		c.apiRequestsCollector = collector
 	}
 }
 
-func NewGitLabClient() *GitLabClient {
-	return NewGitLabClientWithAPIRequestsCollector(NewAPIRequestsCollector())
+func WithCertificateDirectory(certDirectory string) ClientOption {
+	return func(c *GitLabClient) {
+		c.certDirectory = certDirectory
+	}
+}
+
+func NewGitLabClient(options ...ClientOption) *GitLabClient {
+	c := &GitLabClient{}
+	for _, o := range options {
+		o(c)
+	}
+	if c.apiRequestsCollector == nil {
+		c.apiRequestsCollector = NewAPIRequestsCollector()
+	}
+	return c
 }
 
 func getCorrelationID(resp *http.Response, fallbackValue string) string {
